@@ -9,7 +9,7 @@ import tempfile
 
 from os import path
 from pathlib import Path
-from typing import OrderedDict
+from typing import List, Optional, OrderedDict
 from urllib.parse import urlparse, urlencode
 
 from twitchdl import twitch, utils
@@ -51,9 +51,9 @@ def _select_playlist_interactive(playlists):
     print_out("\nAvailable qualities:")
     for n, (name, resolution, uri) in enumerate(playlists):
         if resolution:
-            print_out("{}) {} [{}]".format(n + 1, name, resolution))
+            print_out("{}) <b>{}</b> <dim>({})</dim>".format(n + 1, name, resolution))
         else:
-            print_out("{}) {}".format(n + 1, name))
+            print_out("{}) <b>{}</b>".format(n + 1, name))
 
     no = utils.read_int("Choose quality", min=1, max=len(playlists) + 1, default=1)
     _, _, uri = playlists[no - 1]
@@ -137,7 +137,7 @@ def _clip_target_filename(clip, args):
         raise ConsoleError("Invalid key {} used in --output. Supported keys are: {}".format(e, supported))
 
 
-def _get_vod_paths(playlist, start, end):
+def _get_vod_paths(playlist, start: Optional[int], end: Optional[int]) -> List[str]:
     """Extract unique VOD paths for download from playlist."""
     files = []
     vod_start = 0
@@ -157,7 +157,7 @@ def _get_vod_paths(playlist, start, end):
     return files
 
 
-def _crete_temp_dir(base_uri):
+def _crete_temp_dir(base_uri: str) -> str:
     """Create a temp dir to store downloads if it doesn't exist."""
     path = urlparse(base_uri).path.lstrip("/")
     temp_dir = Path(tempfile.gettempdir(), "twitch-dl", path)
@@ -166,11 +166,11 @@ def _crete_temp_dir(base_uri):
 
 
 def download(args):
-    for video in args.videos:
-        download_one(video, args)
+    for video_id in args.videos:
+        download_one(video_id, args)
 
 
-def download_one(video, args):
+def download_one(video: str, args):
     video_id = utils.parse_video_identifier(video)
     if video_id:
         return _download_video(video_id, args)
@@ -227,7 +227,7 @@ def get_clip_authenticated_url(slug, quality):
     return "{}?{}".format(url, query)
 
 
-def _download_clip(slug, args):
+def _download_clip(slug: str, args) -> None:
     print_out("<dim>Looking up clip...</dim>")
     clip = twitch.get_clip(slug)
     game = clip["game"]["name"] if clip["game"] else "Unknown"
@@ -260,7 +260,7 @@ def _download_clip(slug, args):
     print_out("Downloaded: <blue>{}</blue>".format(target))
 
 
-def _download_video(video_id, args):
+def _download_video(video_id, args) -> None:
     if args.start and args.end and args.end <= args.start:
         raise ConsoleError("End time must be greater than start time")
 
@@ -282,6 +282,9 @@ def _download_video(video_id, args):
             raise ConsoleError("Aborted")
         args.overwrite = True
 
+    # Chapter select or manual offset
+    start, end = _determine_time_range(video_id, args)
+
     print_out("<dim>Fetching access token...</dim>")
     access_token = twitch.get_access_token(video_id, auth_token=args.auth_token)
 
@@ -298,7 +301,7 @@ def _download_video(video_id, args):
 
     base_uri = re.sub("/[^/]+$", "/", playlist_uri)
     target_dir = _crete_temp_dir(base_uri)
-    vod_paths = _get_vod_paths(playlist, args.start, args.end)
+    vod_paths = _get_vod_paths(playlist, start, end)
 
     # Save playlists for debugging purposes
     with open(path.join(target_dir, "playlists.m3u8"), "w") as f:
@@ -341,3 +344,40 @@ def _download_video(video_id, args):
         shutil.rmtree(target_dir)
 
     print_out("\nDownloaded: <green>{}</green>".format(target))
+
+
+def _determine_time_range(video_id, args):
+    if args.start or args.end:
+        return args.start, args.end
+
+    if args.chapter is not None:
+        print_out("<dim>Fetching chapters...</dim>")
+        chapters = twitch.get_video_chapters(video_id)
+
+        if not chapters:
+            raise ConsoleError("This video has no chapters")
+
+        if args.chapter == 0:
+            chapter = _choose_chapter_interactive(chapters)
+        else:
+            try:
+                chapter = chapters[args.chapter - 1]
+            except IndexError:
+                raise ConsoleError(f"Chapter {args.chapter} does not exist. This video has {len(chapters)} chapters.")
+
+        print_out(f'Chapter selected: <blue>{chapter["description"]}</blue>\n')
+        start = chapter["positionMilliseconds"] // 1000
+        duration = chapter["durationMilliseconds"] // 1000
+        return start, start + duration
+
+    return None, None
+
+
+def _choose_chapter_interactive(chapters):
+    print_out("\nChapters:")
+    for index, chapter in enumerate(chapters):
+        duration = utils.format_time(chapter["durationMilliseconds"] // 1000)
+        print_out(f'{index + 1}) <b>{chapter["description"]}</b> <dim>({duration})</dim>')
+    index = utils.read_int("Select a chapter", 1, len(chapters))
+    chapter = chapters[index - 1]
+    return chapter
